# #######################################################################
# (c) Kancelaria Prezesa Rady Ministrów 2015-2018                       #
# Treść licencji w pliku:                                               #
# http://gecon.r-forge.r-project.org/files/gEcon_licence.txt            #
#                                                                       #
# (c) Chancellery of the Prime Minister 2015-2018                       #
# Licence terms can be found in the file:                               #
# http://gecon.r-forge.r-project.org/files/gEcon_licence.txt            #
#                                                                       #
# Author(s): Rafał Głąbski:                                             #
#                -) development, initial version of the model           #
#             Magdalena Krupa:                                          #
#                -) development                                         #
#             Piotr Pomichowski:                                        #
#                -) development, final ver. of the model                #
#                -) model validation                                    #
#                -) scenarios testing                                   #
#                -) closures testing                                    #
#             Michał Opuchlik:                                          #
#                -) development                                         # 
#                -) model validation                                    #
#                -) scenarios testing                                   #
#                -) closures testing                                    #
# #######################################################################
# 4 regions, 8 sectors, benchmark CGE model with international trade    # 
# #######################################################################

# loading packages
library(gEcon)
# library(gEcon.iosam)

###### Setup ######


# set .gcn filename storing the model
model_name <- "cge_DAS-int.gcn"

# reading the model from the file
model <- make_model(model_name)

# load model parameters
initial_par <- read.csv2("init_par.csv")
init_par <- c(initial_par$val)
names(init_par) <- initial_par$parameter

model <- set_free_par(model, init_par[get_par_names(model)])

# load initial values  
initial_val <- read.csv2("init_val.csv")
init_val <- c(initial_val$val)
names(init_val) <- initial_val$varname
model <- initval_var(model, init_val[get_var_names(model)], warnings = TRUE)

# solve the model
model <- steady_state(model, use_jac = TRUE, options_list = list(max_iter = 10, tol = 1e-6))
model_base_copy <- model

# get base steady state values
ss_values_base <- get_ss_values(model, silent = T)

###### Scenario 1 ######
# Non-trading barriers between Country2 (COU2) and Country3 (COU3) decreased by 20%
# scenario implemented using iceberg cost parameters, see also gcn file 


iceberg_params <- grep(pattern = "iceberg_cost.*", x = get_par_names(model = model_base_copy), value = TRUE)
iceberg_cost_old <- get_par_values(model_base_copy, 
                                   iceberg_params, 
                                   silent = T)
iceberg_cost_old <- iceberg_cost_old[c(grep("COU3__COU2", names(iceberg_cost_old)),
                                       grep("COU2__COU3", names(iceberg_cost_old)))]

# trade effectiveness increases as NTBs are lowered so iceberg_cost = iceberg_cost + 0.2  
iceberg_cost_new <- iceberg_cost_old + 0.2
model_scen1 <- set_free_par(model_base_copy, free_par = iceberg_cost_new)

# solve the model
model_scen1 <- steady_state(model_scen1, use_jac = TRUE, options_list = list(max_iter = 10, tol = 1e-6))

# get steady state values (scen1)
ss_values_scen1 <- get_ss_values(model_scen1, silent = T)

###### Scenario 2 ######
# decrease all import taxes between Country2 (COU2) and Country 3 (COU3) by 10%

tmm_params <- grep(pattern = "tmm.*", x = get_par_names(model = model_base_copy), value = TRUE)
tmm_old <- get_par_values(model_base_copy, 
                          tmm_params, 
                          silent = T)
tmm_old <- tmm_old[c(grep("COU3__COU2", names(tmm_old)),
                    grep("COU2__COU3", names(tmm_old)))]

tmm_new <- tmm_old * 0.9
model_scen2 <- set_free_par(model_base_copy, free_par = tmm_new)

# solve the model
model_scen2 <- steady_state(model_scen2, use_jac = TRUE, options_list = list(max_iter = 10, tol = 1e-6))

# get steady state values (scen2)
ss_values_scen2 <- get_ss_values(model_scen2, silent = T)
